package
Version:
v0.1.2
Opens a new window with list of versions in this module.
Published: Apr 9, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
ErrInvalidToken is returned when the provided Telegram bot token is empty or invalid.
New constructs a telebot.Bot using the provided Config.
type Config struct {
Token string
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.