validator

package
v0.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 9, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Module

func Module() fx.Option

func New

func New() *validator.Validate

New creates a new validator instance with required struct validation enabled. WithRequiredStructEnabled ensures that struct fields marked as required are validated even when the struct itself is not explicitly validated.

Types

type Validatable

type Validatable interface {
	Validate() error
}

Validatable can be implemented by request/DTO structs to run custom validation in addition to tag-based validation.

type Validate

type Validate = validator.Validate

Jump to